@@ -13,18 +13,18 @@ class TemporalQuerySet(models.QuerySet):
         today = timezone.now().date()
 
         self.filter(
-            from_date__lte=today,
-            to_date__gt=today,
+            begin__lte=today,
+            end__gt=today,
         ).update(to_date=today)
 
         self.filter(
-            from_date=today,
-            to_date=today,
+            begin=today,
+            end=today,
         ).delete()
 
         return self.create(
-            from_date=today,
-            to_date=date(9999, 1, 1),
+            begin=today,
+            end=date(9999, 1, 1),
             **kwargs
         )
 
@@ -32,6 +32,6 @@ class TemporalQuerySet(models.QuerySet):
         today = timezone.now().date()
 
         return self.filter(
-            from_date__lte=today,
-            to_date__gt=today,
+            begin__lte=today,
+            end__gt=today,
         ).first()
\ No newline at end of file
