@@ -41,6 +41,8 @@ from labor.models import BankAccount
 from labor.models import Salary
 from labor.models import SalaryBlockingItem
 from labor.models import Dependence
+from labor.models import Revenue
+from labor.models import RevenueItem
 
 import calendar
 from random import choice, randint
@@ -113,6 +115,8 @@ class Command(BaseCommand):
         pass
 
     def handle(self, *args, **options):
+        RevenueItem.objects.all().delete()
+        Revenue.objects.all().delete()
 
         TimeSheetItem.objects.all().delete()
         TimeSheet.objects.all().delete()
@@ -866,8 +870,20 @@ class Command(BaseCommand):
                     )
 
                     self.log_timesheets(salary=s,year=year, month=month)
+                    try:
+                        self.generate_revenues(salary=s)
+                    except BaseException as e:
+                        pass
                     self.generate_blocked_salaries(salary=s)
 
+    def generate_revenues(salary: Salary):
+        r = Revenue.objects.create(salary=s)
+        RevenueItem.objects.create(
+            systematic=True,
+            revenue=r,
+            pretence=choice(Pretence.objects.all())
+        )
+
     def generate_blocked_salaries(self, salary: Salary, amount: int = 10, minimum: int = 0, maximum: int = 100000):
         for b in range(0, randint(0, amount)):
             SalaryBlockingItem.objects.create(
