@@ -51,7 +51,8 @@ urlpatterns = [
     path('news/<int:news_id>/rss/', NewsFeed()),
 
     # Permanent redirect to frontend root
-    url('^$', generic.RedirectView.as_view(url='./static/index.html'), name="index"),
+    #url('^$', generic.RedirectView.as_view(url='./static/index.html'), name="index"),
+    url('^$', generic.RedirectView.as_view(url='./workflow/'), name="index"),
 
     path('sitemap.xml', sitemapviews.index, {'sitemaps': sitemaps}),
     path('sitemap-<section>.xml', sitemapviews.sitemap, {'sitemaps': sitemaps}, name='django.contrib.sitemaps.views.sitemap'),
